@@ -6,7 +6,7 @@
  * Magnus Hansson <mah@hms.se>
  * Joakim Wiberg <jow@hms.se>
  *
- * $Id: packet-enip.c 26091 2008-08-26 01:28:50Z wmeier $
+ * $Id: packet-enip.c 27050 2008-12-18 19:08:49Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -207,7 +207,7 @@ dissect_cpf( int command, tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, i
 
 	/* Create item count tree */
 	item_count = tvb_get_letohs( tvb, offset );
-   count_item  = proto_tree_add_text( tree, tvb, offset, 2, "Item Count: %d", item_count );
+	count_item  = proto_tree_add_text( tree, tvb, offset, 2, "Item Count: %d", item_count );
 	count_tree  = proto_item_add_subtree( count_item, ett_count_tree );
 
 	while( item_count-- )
@@ -217,7 +217,7 @@ dissect_cpf( int command, tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, i
 		item_tree = proto_item_add_subtree( type_item, ett_type_tree );
 
 		/* Add length field to item type tree*/
-      proto_tree_add_text( item_tree, tvb, offset+4, 2, "Length: %d", tvb_get_letohs( tvb, offset+4 ) );
+		proto_tree_add_text( item_tree, tvb, offset+4, 2, "Length: %d", tvb_get_letohs( tvb, offset+4 ) );
 
 		item        = tvb_get_letohs( tvb, offset+2 );
 		item_length = tvb_get_letohs( tvb, offset+4 );
@@ -228,221 +228,221 @@ dissect_cpf( int command, tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, i
 
 			switch( item )
 			{
-			   case CONNECTION_BASED:
+			    case CONNECTION_BASED:
 
-			      /* Add Connection identifier */
-			      proto_tree_add_text( item_tree, tvb, offset+6, 4, "Connection Identifier: 0x%08X", tvb_get_letohl( tvb, offset + 6 )  );
+				/* Add Connection identifier */
+				proto_tree_add_text( item_tree, tvb, offset+6, 4, "Connection Identifier: 0x%08X", tvb_get_letohl( tvb, offset + 6 )  );
 
-			      /* Add Connection ID to Info col */
-			      if(check_col(pinfo->cinfo, COL_INFO))
-	            {
-                  col_append_fstr(pinfo->cinfo, COL_INFO,
-				         ", CONID: 0x%08X",
-				         tvb_get_letohl( tvb, offset+6 ) );
-				   }
+				/* Add Connection ID to Info col */
+				if(check_col(pinfo->cinfo, COL_INFO))
+				{
+					col_append_fstr(pinfo->cinfo, COL_INFO,
+							", CONID: 0x%08X",
+							tvb_get_letohl( tvb, offset+6 ) );
+				}
 
-			      break;
+				break;
 
-			   case UNCONNECTED_MSG:
+			    case UNCONNECTED_MSG:
+
+				/* Call dissector for interface */
+				next_tvb = tvb_new_subset( tvb, offset+6, item_length, item_length );
+
+				if( tvb_length(next_tvb) == 0 || !dissector_try_port(subdissector_srrd_table, ifacehndl, next_tvb, pinfo, g_tree) )
+				{
+					/* Show the undissected payload */
+					if( tvb_length_remaining(tvb, offset) > 0 )
+						call_dissector( data_handle, next_tvb, pinfo, g_tree );
+				}
+
+				break;
+
+			    case CONNECTION_TRANSPORT:
+
+				if( command == SEND_UNIT_DATA )
+				{
+					/*
+					** If the encapsulation service is SendUnit Data, this is a
+					** encapsulated connected message
+					*/
+
+					/* Add sequence count ( Transport Class 1,2,3 )*/
+					proto_tree_add_text( item_tree, tvb, offset+6, 2, "Sequence Count: 0x%04X", tvb_get_letohs( tvb, offset+6 ) );
 
 					/* Call dissector for interface */
-					next_tvb = tvb_new_subset( tvb, offset+6, item_length, item_length );
+					next_tvb = tvb_new_subset (tvb, offset+8, item_length-2, item_length-2);
 
-               if( tvb_length(next_tvb) == 0 || !dissector_try_port(subdissector_srrd_table, ifacehndl, next_tvb, pinfo, g_tree) )
-               {
-                  /* Show the undissected payload */
-                   if( tvb_length_remaining(tvb, offset) > 0 )
-                     call_dissector( data_handle, next_tvb, pinfo, g_tree );
-               }
+					if( tvb_length(next_tvb) == 0 || !dissector_try_port(subdissector_sud_table, ifacehndl, next_tvb, pinfo, g_tree) )
+					{
+						/* Show the undissected payload */
+						if( tvb_length_remaining(tvb, offset) > 0 )
+							call_dissector( data_handle, next_tvb, pinfo, g_tree );
+					}
 
-					break;
+				}
+				else
+				{
+					/* Display data */
+					if (tvb_length_remaining(tvb, offset+6) > 0)
+					{
+						next_tvb = tvb_new_subset(tvb, offset+6, item_length, item_length);
+						call_dissector(data_handle, next_tvb, pinfo, item_tree);
+					}
+				} /* End of if send unit data */
 
-            case CONNECTION_TRANSPORT:
-
-               if( command == SEND_UNIT_DATA )
-               {
-                  /*
-                  ** If the encapsulation service is SendUnit Data, this is a
-                  ** encapsulated connected message
-                  */
-
-                  /* Add sequence count ( Transport Class 1,2,3 )*/
-                  proto_tree_add_text( item_tree, tvb, offset+6, 2, "Sequence Count: 0x%04X", tvb_get_letohs( tvb, offset+6 ) );
-
-                  /* Call dissector for interface */
-                  next_tvb = tvb_new_subset (tvb, offset+8, item_length-2, item_length-2);
-
-                  if( tvb_length(next_tvb) == 0 || !dissector_try_port(subdissector_sud_table, ifacehndl, next_tvb, pinfo, g_tree) )
-                  {
-                     /* Show the undissected payload */
-                      if( tvb_length_remaining(tvb, offset) > 0 )
-                        call_dissector( data_handle, next_tvb, pinfo, g_tree );
-                  }
-
-               }
-               else
-               {
-                  /* Display data */
-                  if (tvb_length_remaining(tvb, offset+6) > 0)
-                  {
-                     next_tvb = tvb_new_subset(tvb, offset+6, item_length, item_length);
-                     call_dissector(data_handle, next_tvb, pinfo, item_tree);
-                  }
-               } /* End of if send unit data */
-
-               break;
+				break;
 
 
-            case LIST_IDENTITY_RESP:
+			    case LIST_IDENTITY_RESP:
 
-               /* Encapsulation version */
-               temp_data = tvb_get_letohs( tvb, offset+6 );
-               proto_tree_add_text( item_tree, tvb, offset+6, 2, "Encapsulation Version: %d", temp_data );
+				/* Encapsulation version */
+				temp_data = tvb_get_letohs( tvb, offset+6 );
+				proto_tree_add_text( item_tree, tvb, offset+6, 2, "Encapsulation Version: %d", temp_data );
 
-               /* Socket Address */
-               sockaddr_item = proto_tree_add_text( item_tree, tvb, offset+8, 16, "Socket Address");
-               sockaddr_tree = proto_item_add_subtree( sockaddr_item, ett_sockadd );
+				/* Socket Address */
+				sockaddr_item = proto_tree_add_text( item_tree, tvb, offset+8, 16, "Socket Address");
+				sockaddr_tree = proto_item_add_subtree( sockaddr_item, ett_sockadd );
 
-               /* Socket address struct - sin_family */
-               proto_tree_add_item(sockaddr_tree, hf_enip_lir_sinfamily,
-							tvb, offset+8, 2, FALSE );
+				/* Socket address struct - sin_family */
+				proto_tree_add_item(sockaddr_tree, hf_enip_lir_sinfamily,
+						    tvb, offset+8, 2, FALSE );
 
-               /* Socket address struct - sin_port */
-               proto_tree_add_item(sockaddr_tree, hf_enip_lir_sinport,
-							tvb, offset+10, 2, FALSE );
+				/* Socket address struct - sin_port */
+				proto_tree_add_item(sockaddr_tree, hf_enip_lir_sinport,
+						    tvb, offset+10, 2, FALSE );
 
-               /* Socket address struct - sin_address */
-               proto_tree_add_item(sockaddr_tree, hf_enip_lir_sinaddr,
-							tvb, offset+12, 4, FALSE );
+				/* Socket address struct - sin_address */
+				proto_tree_add_item(sockaddr_tree, hf_enip_lir_sinaddr,
+						    tvb, offset+12, 4, FALSE );
 
-               /* Socket address struct - sin_zero */
-               proto_tree_add_item(sockaddr_tree, hf_enip_lir_sinzero,
-							tvb, offset+16, 8, FALSE );
+				/* Socket address struct - sin_zero */
+				proto_tree_add_item(sockaddr_tree, hf_enip_lir_sinzero,
+						    tvb, offset+16, 8, FALSE );
 
-               /* Vendor ID */
-               proto_tree_add_item(item_tree, hf_enip_lir_vendor,
-							tvb, offset+24, 2, TRUE );
+				/* Vendor ID */
+				proto_tree_add_item(item_tree, hf_enip_lir_vendor,
+						    tvb, offset+24, 2, TRUE );
 
-               /* Device Type */
-               proto_tree_add_item(item_tree, hf_enip_lir_devtype,
-							tvb, offset+26, 2, TRUE );
+				/* Device Type */
+				proto_tree_add_item(item_tree, hf_enip_lir_devtype,
+						    tvb, offset+26, 2, TRUE );
 
-               /* Product Code */
-               proto_tree_add_item(item_tree, hf_enip_lir_prodcode,
-							tvb, offset+28, 2, TRUE );
+				/* Product Code */
+				proto_tree_add_item(item_tree, hf_enip_lir_prodcode,
+						    tvb, offset+28, 2, TRUE );
 
-               /* Revision */
-               temp_data = tvb_get_letohs( tvb, offset+30 );
-               proto_tree_add_text( item_tree, tvb, offset+30, 2, "Revision: %d.%02d", temp_data & 0xFF, ( temp_data & 0xFF00 ) >> 8 );
+				/* Revision */
+				temp_data = tvb_get_letohs( tvb, offset+30 );
+				proto_tree_add_text( item_tree, tvb, offset+30, 2, "Revision: %d.%02d", temp_data & 0xFF, ( temp_data & 0xFF00 ) >> 8 );
 
-               /* Status */
-               proto_tree_add_item(item_tree, hf_enip_lir_status,
-							tvb, offset+32, 2, TRUE );
+				/* Status */
+				proto_tree_add_item(item_tree, hf_enip_lir_status,
+						    tvb, offset+32, 2, TRUE );
 
-               /* Serial Number */
-               proto_tree_add_item(item_tree, hf_enip_lir_serial,
-							tvb, offset+34, 4, TRUE );
+				/* Serial Number */
+				proto_tree_add_item(item_tree, hf_enip_lir_serial,
+						    tvb, offset+34, 4, TRUE );
 
-               /* Product Name Length */
-               name_length = tvb_get_guint8( tvb, offset+38 );
-               proto_tree_add_text( item_tree, tvb, offset+38, 1, "Product Name Length: %d", name_length );
+				/* Product Name Length */
+				name_length = tvb_get_guint8( tvb, offset+38 );
+				proto_tree_add_text( item_tree, tvb, offset+38, 1, "Product Name Length: %d", name_length );
 
-               /* Product Name */
-               proto_tree_add_item(item_tree, hf_enip_lir_name,
-							tvb, offset+39, name_length, TRUE );
+				/* Product Name */
+				proto_tree_add_item(item_tree, hf_enip_lir_name,
+						    tvb, offset+39, name_length, TRUE );
 
-               /* Append product name to info column */
-               if(check_col(pinfo->cinfo, COL_INFO))
-               {
-                  col_append_fstr( pinfo->cinfo, COL_INFO, ", %s",
-                      tvb_format_text(tvb, offset+39, name_length));
-               }
+				/* Append product name to info column */
+				if(check_col(pinfo->cinfo, COL_INFO))
+				{
+					col_append_fstr( pinfo->cinfo, COL_INFO, ", %s",
+							 tvb_format_text(tvb, offset+39, name_length));
+				}
 
-               /* State */
-               proto_tree_add_item(item_tree, hf_enip_lir_state,
-							tvb, offset+name_length+39, 1, TRUE );
-               break;
+				/* State */
+				proto_tree_add_item(item_tree, hf_enip_lir_state,
+						    tvb, offset+name_length+39, 1, TRUE );
+				break;
 
 
-            case SOCK_ADR_INFO_OT:
-            case SOCK_ADR_INFO_TO:
+			    case SOCK_ADR_INFO_OT:
+			    case SOCK_ADR_INFO_TO:
 
-               /* Socket address struct - sin_family */
-               proto_tree_add_item(item_tree, hf_enip_lir_sinfamily,
-							tvb, offset+6, 2, FALSE );
+				/* Socket address struct - sin_family */
+				proto_tree_add_item(item_tree, hf_enip_lir_sinfamily,
+						    tvb, offset+6, 2, FALSE );
 
-               /* Socket address struct - sin_port */
-               proto_tree_add_item(item_tree, hf_enip_lir_sinport,
-							tvb, offset+8, 2, FALSE );
+				/* Socket address struct - sin_port */
+				proto_tree_add_item(item_tree, hf_enip_lir_sinport,
+						    tvb, offset+8, 2, FALSE );
 
-               /* Socket address struct - sin_address */
-               proto_tree_add_item(item_tree, hf_enip_lir_sinaddr,
-							tvb, offset+10, 4, FALSE );
+				/* Socket address struct - sin_address */
+				proto_tree_add_item(item_tree, hf_enip_lir_sinaddr,
+						    tvb, offset+10, 4, FALSE );
 
-               /* Socket address struct - sin_zero */
-               proto_tree_add_item( item_tree, hf_enip_lir_sinzero,
-							tvb, offset+14, 8, FALSE );
-				   break;
+				/* Socket address struct - sin_zero */
+				proto_tree_add_item( item_tree, hf_enip_lir_sinzero,
+						     tvb, offset+14, 8, FALSE );
+				break;
 
 
-            case SEQ_ADDRESS:
-               proto_tree_add_item(item_tree, hf_enip_cpf_sai_connid,
-							tvb, offset+6, 4, TRUE );
+			    case SEQ_ADDRESS:
+				proto_tree_add_item(item_tree, hf_enip_cpf_sai_connid,
+						    tvb, offset+6, 4, TRUE );
 
-               proto_tree_add_item(item_tree, hf_enip_cpf_sai_seqnum,
-							tvb, offset+10, 4, TRUE );
+				proto_tree_add_item(item_tree, hf_enip_cpf_sai_seqnum,
+						    tvb, offset+10, 4, TRUE );
 
-               /* Add info to column */
+				/* Add info to column */
 
-               if(check_col(pinfo->cinfo, COL_INFO))
-	            {
-	               col_clear(pinfo->cinfo, COL_INFO);
+				if(check_col(pinfo->cinfo, COL_INFO))
+				{
+					col_clear(pinfo->cinfo, COL_INFO);
 
-                  col_add_fstr(pinfo->cinfo, COL_INFO,
-				         "Connection:  ID=0x%08X, SEQ=%010d",
-				         tvb_get_letohl( tvb, offset+6 ),
-				         tvb_get_letohl( tvb, offset+10 ) );
-				   }
+					col_add_fstr(pinfo->cinfo, COL_INFO,
+						     "Connection:  ID=0x%08X, SEQ=%010d",
+						     tvb_get_letohl( tvb, offset+6 ),
+						     tvb_get_letohl( tvb, offset+10 ) );
+				}
 
-				   break;
+				break;
 
-            case LIST_SERVICES_RESP:
+			    case LIST_SERVICES_RESP:
 
-               /* Encapsulation version */
-               temp_data = tvb_get_letohs( tvb, offset+6 );
-               proto_tree_add_text( item_tree, tvb, offset+6, 2, "Encapsulation Version: %d", temp_data );
+				/* Encapsulation version */
+				temp_data = tvb_get_letohs( tvb, offset+6 );
+				proto_tree_add_text( item_tree, tvb, offset+6, 2, "Encapsulation Version: %d", temp_data );
 
-               /* Capability flags */
-               temp_data = tvb_get_letohs( tvb, offset+8 );
-               temp_item = proto_tree_add_text(item_tree, tvb, offset+8, 2, "Capability Flags: 0x%04X", temp_data );
-               temp_tree = proto_item_add_subtree(temp_item, ett_lsrcf);
+				/* Capability flags */
+				temp_data = tvb_get_letohs( tvb, offset+8 );
+				temp_item = proto_tree_add_text(item_tree, tvb, offset+8, 2, "Capability Flags: 0x%04X", temp_data );
+				temp_tree = proto_item_add_subtree(temp_item, ett_lsrcf);
 
-               proto_tree_add_item(temp_tree, hf_enip_lsr_tcp,
-                  tvb, offset+8, 2, TRUE );
-      		   proto_tree_add_item(temp_tree, hf_enip_lsr_udp,
-      			   tvb, offset+8, 2, TRUE );
+				proto_tree_add_item(temp_tree, hf_enip_lsr_tcp,
+						    tvb, offset+8, 2, TRUE );
+				proto_tree_add_item(temp_tree, hf_enip_lsr_udp,
+						    tvb, offset+8, 2, TRUE );
 
-               /* Name of service */
-               temp_item = proto_tree_add_text( item_tree, tvb, offset+10, 16, "Name of Service: %s",
-                   tvb_format_stringzpad(tvb, offset+10, 16) );
+				/* Name of service */
+				temp_item = proto_tree_add_text( item_tree, tvb, offset+10, 16, "Name of Service: %s",
+								 tvb_format_stringzpad(tvb, offset+10, 16) );
 
-               /* Append service name to info column */
-               if(check_col(pinfo->cinfo, COL_INFO))
-               {
-                  col_append_fstr( pinfo->cinfo, COL_INFO, ", %s",
-                      tvb_format_stringzpad(tvb, offset+10, 16) );
-               }
+				/* Append service name to info column */
+				if(check_col(pinfo->cinfo, COL_INFO))
+				{
+					col_append_fstr( pinfo->cinfo, COL_INFO, ", %s",
+							 tvb_format_stringzpad(tvb, offset+10, 16) );
+				}
 
-               break;
+				break;
 
 
-           default:
-               if (tvb_length_remaining(tvb, offset+6) > 0)
-               {
-                 next_tvb = tvb_new_subset(tvb, offset+6, item_length, item_length);
-                 call_dissector(data_handle, next_tvb, pinfo, item_tree);
-               }
-               break;
+			    default:
+				if (tvb_length_remaining(tvb, offset+6) > 0)
+				{
+					next_tvb = tvb_new_subset(tvb, offset+6, item_length, item_length);
+					call_dissector(data_handle, next_tvb, pinfo, item_tree);
+				}
+				break;
 
 			} /* end of switch( item type ) */
 
@@ -501,7 +501,9 @@ dissect_enip_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
    /* Set up structures needed to add the protocol subtree and manage it */
    proto_item *ti, *encaph, *csf;
-   proto_tree *enip_tree, *header_tree, *csftree;
+   proto_tree *enip_tree = NULL;
+   proto_tree *header_tree = NULL;
+   proto_tree *csftree;
 
    /* Make entries in Protocol column and Info column on summary display */
    if (check_col(pinfo->cinfo, COL_PROTOCOL))
@@ -510,6 +512,7 @@ dissect_enip_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       col_clear(pinfo->cinfo, COL_INFO);
 
    encap_cmd = tvb_get_letohs( tvb, 0 );
+   encap_data_length = tvb_get_letohs( tvb, 2 );
 
    if( check_col(pinfo->cinfo, COL_INFO) )
    {
@@ -531,10 +534,9 @@ dissect_enip_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
       /* Add service and request/response to info column */
       col_add_fstr(pinfo->cinfo, COL_INFO,
-                "%s (%s)",
-	      val_to_str(encap_cmd, encap_cmd_vals, "Unknown (0x%04x)"),
-	      pkt_type_str );
-
+        "%s (%s)",
+         val_to_str(encap_cmd, encap_cmd_vals, "Unknown (0x%04x)"),
+         pkt_type_str );
 
    } /* end of if( col exists ) */
 
@@ -554,7 +556,6 @@ dissect_enip_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       /* Add EtherNet/IP encapsulation header */
       proto_tree_add_item( header_tree, hf_enip_command, tvb, 0, 2, TRUE );
 
-      encap_data_length = tvb_get_letohs( tvb, 2 );
       proto_tree_add_text( header_tree, tvb, 2, 2, "Length: %u", encap_data_length );
 
       proto_tree_add_item( header_tree, hf_enip_session, tvb, 4, 4, TRUE );
@@ -566,23 +567,25 @@ dissect_enip_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       proto_item_append_text( ti, ", Session: 0x%08X, %s", tvb_get_letohl( tvb, 4 ),
          val_to_str( encap_cmd, encap_cmd_vals, "Unknown (0x%04x)" ) );
 
-      /*
-      ** For some commands we want to add some info to the info column
-      */
+   } /* end of if (tree) */
 
-      if( check_col( pinfo->cinfo, COL_INFO ) )
+   /*
+   ** For some commands we want to add some info to the info column
+   */
+
+   if( check_col( pinfo->cinfo, COL_INFO ) )
+   {
+
+      switch( encap_cmd )
       {
+         case REGISTER_SESSION:
+         case UNREGISTER_SESSION:
+               col_append_fstr( pinfo->cinfo, COL_INFO, ", Session: 0x%08X",
+                                tvb_get_letohl( tvb, 4 ) );
 
-         switch( encap_cmd )
-         {
-            case REGISTER_SESSION:
-            case UNREGISTER_SESSION:
-                  col_append_fstr( pinfo->cinfo, COL_INFO, ", Session: 0x%08X",
-                                   tvb_get_letohl( tvb, 4 ) );
+      } /* end of switch() */
 
-         } /* end of switch() */
-
-      } /* end of id info column */
+   } /* end of id info column */
 
       /* Command specific data - create tree */
       if( encap_data_length )
@@ -658,7 +661,6 @@ dissect_enip_pdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
       } /* end of if( encapsulated data ) */
 
-   }
 } /* end of dissect_enip_pdu() */
 
 static int
@@ -698,7 +700,7 @@ dissect_enip_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       return 0;	/* not a known command */
 
    tcp_dissect_pdus(tvb, pinfo, tree, enip_desegment, 4,
-	get_enip_pdu_len, dissect_enip_pdu);
+      get_enip_pdu_len, dissect_enip_pdu);
    return tvb_length(tvb);
 }
 
@@ -708,7 +710,7 @@ dissect_enipio(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
    /* Set up structures needed to add the protocol subtree and manage it */
 	proto_item *ti;
-	proto_tree *enip_tree;
+	proto_tree *enip_tree = NULL;
 	guint16 type_id;
 
 	g_tree = tree;
@@ -729,15 +731,15 @@ dissect_enipio(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
    necessary to generate protocol tree items. */
 	if (tree)
 	{
-      /* create display subtree for the protocol */
+	  /* create display subtree for the protocol */
 		ti = proto_tree_add_item(tree, proto_enip, tvb, 0, -1, FALSE);
 
 		enip_tree = proto_item_add_subtree(ti, ett_enip);
-
-      dissect_cpf( 0xFFFF, tvb, pinfo, enip_tree, 0, 0 );
 	}
 
-   return tvb_length(tvb);
+	dissect_cpf( 0xFFFF, tvb, pinfo, enip_tree, 0, 0 );
+
+	return tvb_length(tvb);
 } /* end of dissect_enipio() */
 
 
@@ -770,7 +772,7 @@ proto_register_enip(void)
 		{ &hf_enip_sendercontex,
 			{ "Sender Context", "enip.context",
 			FT_BYTES, BASE_HEX, NULL, 0,
-			"Information pertient to the sender", HFILL }
+			"Information pertinent to the sender", HFILL }
 		},
 		{ &hf_enip_options,
 			{ "Options", "enip.options",
@@ -880,7 +882,7 @@ proto_register_enip(void)
 		&ett_enip,
 		&ett_count_tree,
 		&ett_type_tree,
-	&ett_command_tree,
+		&ett_command_tree,
 		&ett_sockadd,
 		&ett_lsrcf,
 	};
@@ -900,10 +902,10 @@ proto_register_enip(void)
 	    "Whether the EtherNet/IP dissector should desegment all messages spanning multiple TCP segments",
 	    &enip_desegment);
 
-   subdissector_sud_table = register_dissector_table("enip.sud.iface",
+	subdissector_sud_table = register_dissector_table("enip.sud.iface",
 		"SendUnitData.Interface Handle", FT_UINT32, BASE_HEX);
 
-   subdissector_srrd_table = register_dissector_table("enip.srrd.iface",
+	subdissector_srrd_table = register_dissector_table("enip.srrd.iface",
 		"SendRequestReplyData.Interface Handle", FT_UINT32, BASE_HEX);
 
 } /* end of proto_register_enip() */
