@@ -2,7 +2,7 @@
  * Routines for IPMI dissection
  * Copyright 2002-2008, Alexey Neyman, Pigeon Point Systems <avn@pigeonpoint.com>
  *
- * $Id: packet-ipmi.c 25952 2008-08-07 20:58:27Z guy $
+ * $Id: packet-ipmi.c 27994 2009-04-08 13:07:21Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -63,7 +63,7 @@ struct ipmi_netfn_root {
 
 /* We need more than a conversation. Over the same RMCP session 
    (or IPMB), there may be several addresses/SWIDs. Thus, in a single
-   Ethereal-maintained conversation we might need to find our own... */
+   Wireshark-maintained conversation we might need to find our own... */
 struct ipmi_saved_data {
 	guint32 set_data;
 	guint32 saved_data[NSAVED_DATA];
