@@ -2,7 +2,7 @@
  * Routines for NTP packet dissection
  * Copyright 1999, Nathan Neulinger <nneul@umr.edu>
  *
- * $Id: packet-ntp.c 25056 2008-04-15 21:45:46Z gerald $
+ * $Id: packet-ntp.c 27930 2009-04-02 03:55:37Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -113,8 +113,8 @@ static const value_string li_types[] = {
 
 static const value_string ver_nums[] = {
 	{ 0,	"reserved" },
-	{ 1,	"reserved" },
-	{ 2,	"reserved" },
+	{ 1,	"NTP Version 1" },
+	{ 2,	"NTP Version 2" },
 	{ 3,	"NTP Version 3" },
 	{ 4,	"NTP Version 4" },
 	{ 5,	"reserved" },
@@ -514,7 +514,7 @@ dissect_ntp_std(tvbuff_t *tvb, proto_tree *ntp_tree, guint8 flags)
 	ppoll = tvb_get_guint8(tvb, 2);
 	proto_tree_add_uint_format(ntp_tree, hf_ntp_ppoll, tvb, 2, 1,
 				   ppoll,
-				   (((ppoll >= 4) && (ppoll <= 16)) ?
+				   (((ppoll >= 4) && (ppoll <= 17)) ?
 				   "Peer Polling Interval: %u (%u sec)" :
 				   "Peer Polling Interval: invalid (%u)"),
 				   ppoll,
