@@ -1,7 +1,7 @@
 /* rpc_stat.c
  * rpc_stat   2002 Ronnie Sahlberg
  *
- * $Id: rpc_stat.c 26643 2008-10-31 10:33:20Z stig $
+ * $Id: rpc_stat.c 29099 2009-07-15 00:10:08Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -256,7 +256,8 @@ gtk_rpcstat_init(const char *optarg, void* userdata _U_)
 	hf_index=rpc_prog_hf(rpc_program, rpc_version);
 	hfi=proto_registrar_get_nth(hf_index);
 
-	rs->win=window_new(GTK_WINDOW_TOPLEVEL, "rpc-stat");
+	rs->win = dlg_window_new("rpc-stat");  /* transient_for top_level */
+	gtk_window_set_destroy_with_parent (GTK_WINDOW(rs->win), TRUE);
 	gtk_window_set_default_size(GTK_WINDOW(rs->win), 550, 400);
 	rpcstat_set_title(rs);
 
@@ -372,7 +373,7 @@ rpcstat_program_select(GtkWidget *item _U_, gpointer key)
 	for(i=rpc_min_vers;i<=rpc_max_vers;i++){
 		GtkWidget *menu_item;
 		char vs[5];
-		g_snprintf(vs, 5, "%d",i);
+		g_snprintf(vs, sizeof(vs), "%d",i);
 		menu_item=gtk_menu_item_new_with_label(vs);
 		g_signal_connect(menu_item, "activate", G_CALLBACK(rpcstat_version_select),
                                (gpointer)(long) i);
@@ -473,7 +474,7 @@ gtk_rpcstat_cb(GtkWidget *w _U_, gpointer d _U_)
 	for(i=rpc_min_vers;i<=rpc_max_vers;i++){
 		GtkWidget *menu_item;
 		char vs[5];
-		g_snprintf(vs, 5, "%d",i);
+		g_snprintf(vs, sizeof(vs), "%d",i);
 		menu_item=gtk_menu_item_new_with_label(vs);
 		g_signal_connect(menu_item, "activate", G_CALLBACK(rpcstat_version_select),
                                (gpointer)(long) i);
